@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2020 A S Lewis
+# Copyright (C) 2019-2021 A S Lewis
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -220,11 +220,13 @@ class DialogueManager(threading.Thread):
                 The parent window for the dialogue window. If None, the main
                 window is used as the parent window
 
-            action (Gtk.FileChooserAction or None): The type of fille chooser
-                to create. If None, Gtk.FileChooserAction.SAVE is used
+            action (str or None): The type of fille chooser
+                to create: 'open' to set a file for opening, 'save' to save a
+                file, or 'folder' to select a folder
 
-            file_path (str or None): If not None, the file path to suggest to
-                the user
+            file_path (str or None): The file path to suggest to the user. If
+                not specified, then the file chooser is opened in Tartube's
+                data directory
 
         Returns:
 
@@ -237,6 +239,12 @@ class DialogueManager(threading.Thread):
 
         if action is None:
             action = Gtk.FileChooserAction.SAVE
+        elif action == 'open':
+            action = Gtk.FileChooserAction.OPEN
+        elif action == 'folder':
+            action = Gtk.FileChooserAction.SELECT_FOLDER
+        else:
+            action = Gtk.FileChooserAction.SAVE
 
         # Create the file chooser dialogue
         dialogue_win = FileChooserDialogue(
@@ -250,8 +258,17 @@ class DialogueManager(threading.Thread):
         )
 
         if file_path is not None:
+
             dialogue_win.set_current_name(file_path)
 
+        elif self.app_obj.data_dir:
+
+            # Yes, Gtk discourages this, but they aren't the ones who have to
+            #   click through a million folders to find a suitable one
+            # The calling code can override this call with its own one, if
+            #   necessary
+            dialogue_win.set_current_folder(self.app_obj.data_dir)
+
         # Save the universe
         dialogue_win.set_default_size(
             self.app_obj.config_win_width,
