@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2020 A S Lewis
+# Copyright (C) 2019-2021 A S Lewis
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -38,6 +38,8 @@ from mainapp import _
 locale_setup_list = [
     'en_GB',    'English',
     'en_US',    'English (American)',
+    'ko_KR',    '한국어',
+    'nl_NL',    'Nederlands',
 ]
 
 LOCALE_DEFAULT = locale_setup_list[0]
@@ -798,7 +800,8 @@ def do_translate(config_flag=False):
 
     global FOLDER_ALL_VIDEOS, FOLDER_BOOKMARKS, FOLDER_FAVOURITE_VIDEOS, \
     FOLDER_LIVESTREAMS, FOLDER_MISSING_VIDEOS, FOLDER_NEW_VIDEOS, \
-    FOLDER_WAITING_VIDEOS, FOLDER_TEMPORARY_VIDEOS, FOLDER_UNSORTED_VIDEOS
+    FOLDER_RECENT_VIDEOS, FOLDER_WAITING_VIDEOS, FOLDER_TEMPORARY_VIDEOS, \
+    FOLDER_UNSORTED_VIDEOS
 
     global YTDL_UPDATE_DICT
 
@@ -823,6 +826,7 @@ def do_translate(config_flag=False):
     FOLDER_LIVESTREAMS = _('Livestreams')
     FOLDER_MISSING_VIDEOS = _('Missing Videos')
     FOLDER_NEW_VIDEOS = _('New Videos')
+    FOLDER_RECENT_VIDEOS = _('Recent Videos')
     FOLDER_WAITING_VIDEOS = _('Waiting Videos')
     FOLDER_TEMPORARY_VIDEOS = _('Temporary Videos')
     FOLDER_UNSORTED_VIDEOS = _('Unsorted Videos')
@@ -833,6 +837,8 @@ def do_translate(config_flag=False):
             _('Update using default youtube-dl path'),
         'ytdl_update_local_path':
             _('Update using local youtube-dl path'),
+        'ytdl_update_custom_path':
+            _('Update using custom youtube-dl path'),
         'ytdl_update_pip':
             _('Update using pip'),
         'ytdl_update_pip_omit_user':
