@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019-2020 A S Lewis
+# Copyright (C) 2019-2021 A S Lewis
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -610,7 +610,7 @@ def disk_get_free_space(path, bytes_flag=False):
         return 0
 
 
-def disk_get_total_space(path, bytes_flag=False):
+def disk_get_total_space(path=None, bytes_flag=False):
 
     """Can be called by anything.
 
@@ -626,21 +626,30 @@ def disk_get_total_space(path, bytes_flag=False):
 
     Returns:
 
-        The total size in MB (or in bytes, if the flag is specified)
+        The total size in MB (or in bytes, if the flag is specified). If no
+        path or an invalid path is specified, returns 0
 
     """
 
-    total_bytes, used_bytes, free_bytes = shutil.disk_usage(
-        os.path.realpath(path),
-    )
+    if path is None \
+    or (
+        not os.path.isdir(path) and not os.path.isfile(path)
+    ):
+        return 0
 
-    if not bytes_flag:
-        return int(total_bytes / 1000000)
     else:
-        return total_bytes
+
+        total_bytes, used_bytes, free_bytes = shutil.disk_usage(
+            os.path.realpath(path),
+        )
+
+        if not bytes_flag:
+            return int(total_bytes / 1000000)
+        else:
+            return total_bytes
 
 
-def disk_get_used_space(path, bytes_flag=False):
+def disk_get_used_space(path=None, bytes_flag=False):
 
     """Can be called by anything.
 
@@ -657,18 +666,27 @@ def disk_get_used_space(path, bytes_flag=False):
 
     Returns:
 
-        The used space in MB (or in bytes, if the flag is specified)
+        The used space in MB (or in bytes, if the flag is specified). If no
+        path or an invalid path is specified, returns 0
 
     """
 
-    total_bytes, used_bytes, free_bytes = shutil.disk_usage(
-        os.path.realpath(path),
-    )
+    if path is None \
+    or (
+        not os.path.isdir(path) and not os.path.isfile(path)
+    ):
+        return 0
 
-    if not bytes_flag:
-        return int(used_bytes / 1000000)
     else:
-        return used_bytes
+
+        total_bytes, used_bytes, free_bytes = shutil.disk_usage(
+            os.path.realpath(path),
+        )
+
+        if not bytes_flag:
+            return int(used_bytes / 1000000)
+        else:
+            return used_bytes
 
 
 def extract_livestream_data(stderr):
@@ -1224,13 +1242,6 @@ divert_mode=None):
     if app_obj.ytdl_write_verbose_flag:
         options_list.append('--verbose')
 
-    # Specify a standard location for the cookie jar (otherwise youtube-dl
-    #   will write it to ../tartube/tartube)
-    options_list.append('--cookies')
-    options_list.append(
-        os.path.abspath(os.path.join(app_obj.data_dir, 'cookies.txt')),
-    )
-
     # Supply youtube-dl with the path to the ffmpeg/avconv binary, if the
     #   user has provided one
     # If both paths have been set, prefer ffmpeg, unless the 'prefer_avconv'
@@ -1262,8 +1273,12 @@ divert_mode=None):
     if os.name != 'nt':
         ytdl_path = re.sub('^\~', os.path.expanduser('~'), ytdl_path)
 
-    # Set the list
-    cmd_list = [ytdl_path] + options_list + [source]
+    # Set the list. At the moment, a custom path must be preceeded by 'python3'
+    #   (Git #243)
+    if app_obj.ytdl_path_custom_flag:
+        cmd_list = ['python3'] + [ytdl_path] + options_list + [source]
+    else:
+        cmd_list = [ytdl_path] + options_list + [source]
 
     return cmd_list
 
@@ -1292,7 +1307,7 @@ def get_encoding():
 def get_local_time():
 
     """Can be called by anything.
-    
+
     Returns a datetime object that has been converted from UTC to the local
     time zone.
 
@@ -1304,7 +1319,7 @@ def get_local_time():
 
     utc = datetime.datetime.utcfromtimestamp(time.time())
     return utc.replace(tzinfo=datetime.timezone.utc).astimezone(tz=None)
-    
+
 
 def get_options_manager(app_obj, media_data_obj):
 
